# ConversionGraph Internals

!!! note "Coming Soon"
    This page is under construction.

<!-- Content outline:
- Graph topology: ~43 edges, ~15 dimension partitions
- BFS path finding: why BFS, not Dijkstra/DFS/A*
- The visited dict's dual role
- No caching: why, and when this might change
- Map types: LinearMap, AffineMap, LogMap
- Edge addition and injectable pattern
-->
